@@ -152,7 +152,7 @@ def check_rulelist(rl):
 
 class RuleList:
     """This class represents a rulelist. It is used to store the model generated by 
-    `CorelsClassifier.fit`.
+    `FairCorelsClassifier.fit`.
     
     Attributes
     ----------
